@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.18
+# Version   : 0.2.19
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -579,9 +579,6 @@ class AFM:
                 adjusted_retract =  np.append(adjusted_retract, blank)
                 _z_w = np.append(_z_w, blank)
 
-            if len(adjusted_approach) < 10 or len(adjusted_retract) < 10 :
-                continue
-
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
 
                 if self.file_name[-3:] != 'nid':
